@@ -42,9 +42,9 @@ class RuntimeJob:
     """Representation of a runtime program execution.
 
     A new ``RuntimeJob`` instance is returned when you call
-    :meth:`IBMRuntimeService.run<qiskit_ibm_runtime.IBMRuntimeService.run>`
+    :meth:`QiskitRuntimeService.run<qiskit_ibm_runtime.QiskitRuntimeService.run>`
     to execute a runtime program, or
-    :meth:`IBMRuntimeService.job<qiskit_ibm_runtime.IBMRuntimeService.job>`
+    :meth:`QiskitRuntimeService.job<qiskit_ibm_runtime.QiskitRuntimeService.job>`
     to retrieve a previously executed job.
 
     If the program execution is successful, you can inspect the job's status by
@@ -65,7 +65,7 @@ class RuntimeJob:
 
     If the program has any interim results, you can use the ``callback``
     parameter of the
-    :meth:`~qiskit_ibm_runtime.IBMRuntimeService.run`
+    :meth:`~qiskit_ibm_runtime.QiskitRuntimeService.run`
     method to stream the interim results along with the final result.
     Alternatively, you can use the :meth:`stream_results` method to stream
     the results at a later time, but before the job finishes.
