@@ -20,13 +20,13 @@ from qiskit_ibm_runtime.accounts import Account
 from qiskit_ibm_runtime.api.client_parameters import ClientParameters
 from qiskit_ibm_runtime.api.clients import AuthClient
 from qiskit_ibm_runtime.hub_group_project import HubGroupProject
-from qiskit_ibm_runtime.ibm_runtime_service import IBMRuntimeService
+from qiskit_ibm_runtime.qiskit_runtime_service import QiskitRuntimeService
 from .fake_account_client import BaseFakeAccountClient
 from .fake_runtime_client import BaseFakeRuntimeClient
 
 
-class FakeRuntimeService(IBMRuntimeService):
-    """Creates an IBMRuntimeService instance with mocked hub/group/project.
+class FakeRuntimeService(QiskitRuntimeService):
+    """Creates an QiskitRuntimeService instance with mocked hub/group/project.
 
     By default there are 2 h/g/p - `hub0/group0/project0` and `hub1/group1/project1`.
     Each h/g/p has 2 backends - `common_backend` and `unique_backend_<idx>`.
@@ -47,7 +47,7 @@ class FakeRuntimeService(IBMRuntimeService):
         self._fake_account_client = test_options.get("account_client")
 
         with mock.patch(
-            "qiskit_ibm_runtime.ibm_runtime_service.RuntimeClient",
+            "qiskit_ibm_runtime.qiskit_runtime_service.RuntimeClient",
             new=BaseFakeRuntimeClient,
         ):
             super().__init__(*args, **kwargs)
